using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using HiGames;

namespace HiToText
{
    class Program
    {
        private enum Flags
        {
            None,
            Read,
            Write,
            Format
        }

        static void Main(string[] args)
        {
            Flags flag = Flags.None;
            string fileName = null;
            string romName = null;
            List<string> scoreData = new List<string>();
            Hiscore game = null;

            if (args.Length == 0)
            {
                WriteUsage();
                return;
            }

            switch(args[0].ToLower())
            {
                case "-r":
                    flag = Flags.Read;
                    break;
                case "-w":
                    flag = Flags.Write;
                    break;
                case "-f":
                    flag = Flags.Format;
                    break;
                default:
                    WriteUsage();
                    return;
            }

            if(args.Length >= 2)
            {
                fileName = args[1];
                romName = Path.GetFileNameWithoutExtension(fileName);

                if (!File.Exists(fileName))
                {
                    WriteUsage();
                    Console.WriteLine(String.Format("File Not Found: {0}", fileName));
                    return;
                }

                switch (romName)
                {
                    case "1942":
                        game = new _1942(fileName);
                        break;
                    case "asterix":
                        game = new asterix(fileName);
                        break;
                    case "btime":
                        game = new btime(fileName);
                        break;
                    case "ckong":
                        game = new ckong(fileName);
                        break;
                    case "contra":
                        game = new contra(fileName);
                        break;
                    case "ddonpach":
                        game = new ddonpach(fileName);
                        break;
                    case "digdug":
                        game = new digdug(fileName);
                        break;
                    case "digdug2":
                        game = new digdug2(fileName);
                        break;
                    case "dkong":
                        game = new dkong(fileName);
                        break;
                    case "dkong3":
                        game = new dkong3(fileName);
                        break;
                    case "dkongjr":
                        game = new dkongjr(fileName);
                        break;
                    case "frogger":
                        game = new frogger(fileName);
                        break;
                    case "galaga":
                        game = new galaga(fileName);
                        break;
                    case "galaxian":
                        game = new galaxian(fileName);
                        break;
                    case "gigawing":
                        game = new gigawing(fileName);
                        break;
                    case "gng":
                        game = new gng(fileName);
                        break;
                    case "jackal":
                        game = new jackal(fileName);
                        break;
                    case "mappy":
                        game = new mappy(fileName);
                        break;
                    case "marble":
                        game = new marble(fileName);
                        break;
                    case "mario":
                        game = new mario(fileName);
                        break;
                    case "mhavoc":
                        game = new mhavoc(fileName);
                        break;
                    case "mrdo":
                        game = new mrdo(fileName);
                        break;
                    case "msword":
                        game = new msword(fileName);
                        break;
                    case "mspacman":
                    case "pacman":
                        game = new pacman(fileName);
                        break;
                    case "pulstar":
                        game = new pulstar(fileName);
                        break;
                    case "raiden":
                        game = new raiden(fileName);
                        break;
                    case "sf2":
                        game = new sf2(fileName);
                        break;
                    case "suprmrio":
                        game = new suprmrio(fileName);
                        break;
                    case "wb3":
                        game = new wb3(fileName);
                        break;
                    case "zaxxon":
                        game = new zaxxon(fileName);
                        break;
                    default:
                        WriteUsage();
                        Console.WriteLine(String.Format("ROM Not Supported: {0}", romName));
                        return;
                }
            }

            for(int i = 2; i< args.Length; i++)
                scoreData.Add(args[i]);

            switch(flag)
            {
                case Flags.Read:
                    Console.WriteLine(game.HiToString());
                    break;
                case Flags.Write:
                    if (scoreData.Count == game.FieldCount)
                    {
                        game.SetHiScore(scoreData.ToArray());
                        game.SaveData();
                    }
                    else
                    {
                        WriteUsage();
                        Console.WriteLine(String.Format("Error: Expecting {0} Entries", game.FieldCount));
                    }
                    break;
                case Flags.Format:
                    Console.WriteLine(game.Format);
                    break;
            }
        }

        public static void WriteUsage()
        {
            Console.WriteLine("USAGE: HiToText [-r|-w|-f] [FILENAME] [SCORE_DATA_SEPARATED_BY_SPACES]");
            Console.WriteLine();
            Console.WriteLine("-r : Read   Eg. HiToText -r galaga.hi");
            Console.WriteLine("-w : Write  Eg. HiToText -w galaga.hi 0 1000 FOO");
            Console.WriteLine("-f : Format Eg. HiToText -f");
            Console.WriteLine();
            Console.WriteLine("NOTE: To write a hiscore entry, view the format first to get the score data format");
            Console.WriteLine();
        }
    }
}
